@@ -75,9 +75,9 @@ case "$1" in
     ;;
 esac
 
-# Automatically added by dh_systemd_enable/13.3.4
+# Automatically added by dh_systemd_enable/13.11.4
 if [ "$1" = "configure" ] || [ "$1" = "abort-upgrade" ] || [ "$1" = "abort-deconfigure" ] || [ "$1" = "abort-remove" ] ; then
-	# This will only remove masks created by d-s-h on package removal.
+	# The following line should be removed in trixie or trixie+1
 	deb-systemd-helper unmask 'benno-archive.service' >/dev/null || true
 
 	# was-enabled defaults to true, so new installations run enable.
@@ -92,9 +92,9 @@ if [ "$1" = "configure" ] || [ "$1" = "abort-upgrade" ] || [ "$1" = "abort-decon
 	fi
 fi
 # End automatically added section
-# Automatically added by dh_installinit/13.3.4
+# Automatically added by dh_installinit/13.11.4
 if [ "$1" = "configure" ] || [ "$1" = "abort-upgrade" ] || [ "$1" = "abort-deconfigure" ] || [ "$1" = "abort-remove" ] ; then
-	if [ -x "/etc/init.d/benno-archive" ]; then
+	if [ -z "${DPKG_ROOT:-}" ] && [ -x "/etc/init.d/benno-archive" ]; then
 		update-rc.d benno-archive defaults >/dev/null
 		if [ -n "$2" ]; then
 			_dh_action=restart
